summaryrefslogtreecommitdiff
path: root/epan/srt_table.h
diff options
context:
space:
mode:
authorDario Lombardo <lomato@gmail.com>2016-06-23 17:35:17 +0200
committerAnders Broman <a.broman58@gmail.com>2016-06-26 06:01:22 +0000
commitbfb6f62e368825d862d2ceac91662a6e6de06ddd (patch)
tree774a33c6b1fc706193ededc47d22c82e59aa07ba /epan/srt_table.h
parentb845e29d97c9f30c8e7369835f084af19455cbbb (diff)
downloadwireshark-bfb6f62e368825d862d2ceac91662a6e6de06ddd.tar.gz
srt: rename shadow variable
Change-Id: I69bda25f79b6b46bdb288e32133847a853b614e0 Reviewed-on: https://code.wireshark.org/review/16101 Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan/srt_table.h')
-rw-r--r--epan/srt_table.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/epan/srt_table.h b/epan/srt_table.h
index 63159db4b4..cc407d7d2d 100644
--- a/epan/srt_table.h
+++ b/epan/srt_table.h
@@ -32,7 +32,7 @@ extern "C" {
/** Procedure data */
typedef struct _srt_procedure_t {
- int index;
+ int proc_index;
timestat_t stats; /**< stats */
char *procedure; /**< column entries */
} srt_procedure_t;
@@ -206,19 +206,19 @@ WS_DLL_PUBLIC srt_stat_table* init_srt_table(const char *name, const char *short
/** Init an srt table row data structure.
*
* @param rst the srt table
* @param index number of procedure
* @param procedure the procedures name
*/
-WS_DLL_PUBLIC void init_srt_table_row(srt_stat_table *rst, int index, const char *procedure);
+WS_DLL_PUBLIC void init_srt_table_row(srt_stat_table *rst, int proc_index, const char *procedure);
/** Add srt response to table row data.
*
* @param rst the srt table
* @param index number of procedure
* @param req_time the time of the corresponding request
* @param pinfo current packet info
*/
-WS_DLL_PUBLIC void add_srt_table_data(srt_stat_table *rst, int index, const nstime_t *req_time, packet_info *pinfo);
+WS_DLL_PUBLIC void add_srt_table_data(srt_stat_table *rst, int proc_index, const nstime_t *req_time, packet_info *pinfo);
#ifdef __cplusplus
@@ -206,19 +206,19 @@ WS_DLL_PUBLIC srt_stat_table* init_srt_table(const char *name, const char *short
*
* @param rst the srt table
- * @param index number of procedure
+ * @param proc_index number of procedure
* @param procedure the procedures name
*/
@@ -206,19 +206,19 @@ WS_DLL_PUBLIC srt_stat_table* init_srt_table(const char *name, const char *short
*
* @param rst the srt table
- * @param index number of procedure
+ * @param proc_index number of procedure
* @param req_time the time of the corresponding request
* @param pinfo current packet info